==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/TargetStatusFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TargetStatusFluent<A extends TargetStatusFluent<A>> extends BaseFluent<A>{
  public TargetStatusFluent() {
  }
  public TargetStatusFluent(TargetStatus instance) {
    instance = (instance != null ? instance : new TargetStatus());

    if (instance != null) {
      this.withTargetable(instance.getTargetable());
      this.withTargetable(instance.getTargetable());
    }
  }
  private TargetableBuilder targetable;
  public Targetable buildTargetable() {
    return this.targetable!=null ?this.targetable.build():null;
  }
  public A withTargetable(Targetable targetable) {
    _visitables.get("targetable").remove(this.targetable);
    if (targetable!=null){ this.targetable= new TargetableBuilder(targetable); _visitables.get("targetable").add(this.targetable);} else { this.targetable = null; _visitables.get("targetable").remove(this.targetable); } return (A) this;
  }
  public boolean hasTargetable() {
    return this.targetable != null;
  }
  public A withNewTargetable(String domainInternal) {
    return (A)withTargetable(new Targetable(domainInternal));
  }
  public TargetableNested<A> withNewTargetable() {
    return new TargetableNested(null);
  }
  public TargetableNested<A> withNewTargetableLike(Targetable item) {
    return new TargetableNested(item);
  }
  public TargetableNested<A> editTargetable() {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(null));
  }
  public TargetableNested<A> editOrNewTargetable() {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(new TargetableBuilder().build()));
  }
  public TargetableNested<A> editOrNewTargetableLike(Targetable item) {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TargetStatusFluent that = (TargetStatusFluent) o;
    if (!java.util.Objects.equals(targetable, that.targetable)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(targetable,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (targetable != null) { sb.append("targetable:"); sb.append(targetable); }
    sb.append("}");
    return sb.toString();
  }
  public class TargetableNested<N> extends TargetableFluent<TargetableNested<N>> implements Nested<N>{
    TargetableNested(Targetable item) {
      this.builder = new TargetableBuilder(this, item);
    }
    TargetableBuilder builder;
    public N and() {
      return (N) TargetStatusFluent.this.withTargetable(builder.build());
    }
    public N endTargetable() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/TargetStatusFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TargetStatusFluent<A extends TargetStatusFluent<A>> extends BaseFluent<A>{
  public TargetStatusFluent() {
  }
  
  public TargetStatusFluent(TargetStatus instance) {
    this.copyInstance(instance);
  }
  private TargetableBuilder targetable;
  
  protected void copyInstance(TargetStatus instance) {
    instance = (instance != null ? instance : new TargetStatus());
  
    if (instance != null) {
        this.withTargetable(instance.getTargetable());
        this.withTargetable(instance.getTargetable());
      }
  }
  
  public Targetable buildTargetable() {
    return this.targetable!=null ?this.targetable.build():null;
  }
  
  public A withTargetable(Targetable targetable) {
    _visitables.get("targetable").remove(this.targetable);
    if (targetable!=null){ this.targetable= new TargetableBuilder(targetable); _visitables.get("targetable").add(this.targetable);} else { this.targetable = null; _visitables.get("targetable").remove(this.targetable); } return (A) this;
  }
  
  public boolean hasTargetable() {
    return this.targetable != null;
  }
  
  public A withNewTargetable(String domainInternal) {
    return (A)withTargetable(new Targetable(domainInternal));
  }
  
  public TargetableNested<A> withNewTargetable() {
    return new TargetableNested(null);
  }
  
  public TargetableNested<A> withNewTargetableLike(Targetable item) {
    return new TargetableNested(item);
  }
  
  public TargetableNested<A> editTargetable() {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(null));
  }
  
  public TargetableNested<A> editOrNewTargetable() {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(new TargetableBuilder().build()));
  }
  
  public TargetableNested<A> editOrNewTargetableLike(Targetable item) {
    return withNewTargetableLike(java.util.Optional.ofNullable(buildTargetable()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TargetStatusFluent that = (TargetStatusFluent) o;
    if (!java.util.Objects.equals(targetable, that.targetable)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(targetable,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (targetable != null) { sb.append("targetable:"); sb.append(targetable); }
    sb.append("}");
    return sb.toString();
  }
  public class TargetableNested<N> extends TargetableFluent<TargetableNested<N>> implements Nested<N>{
    TargetableNested(Targetable item) {
      this.builder = new TargetableBuilder(this, item);
    }
    TargetableBuilder builder;
    
    public N and() {
      return (N) TargetStatusFluent.this.withTargetable(builder.build());
    }
    
    public N endTargetable() {
      return and();
    }
    
  
  }

}
